@@ -5,15 +5,16 @@ DAY = datetime.timedelta(days=1)
 import re
 from vinca.lib.ansi import ansi, AnsiStr
 
-def filter(cards,
+def query(cards, pattern='', no_fancy=False,
 	   tags_include=None, tags_exclude=None, decks=None,
 	   create_date_min=None, create_date_max=None,
 	   seen_date_min=None, seen_date_max=None,
 	   due_date_min=None, due_date_max=None,
-	   due_only=False, not_due_only = False,
 	   editor=None, reviewer=None, scheduler=None,
-	   deleted_only=False, not_deleted_only=False,
-	   new_only=False, not_new_only=False):
+	   deleted_only=False, show_deleted=False,
+	   due_only=False, not_due_only = False,
+	   new_only=False, not_new_only=False,
+	   invert=False):
 	
 	# initializing a parameter to [] will cause bugs
 	# since lists are mutable and parameters are created
@@ -23,6 +24,8 @@ def filter(cards,
 	tags_exclude = tags_exclude if tags_exclude else []
 	tags_include += [t for d in decks for t in d.tags_include]
 	tags_exclude += [t for d in decks for t in d.tags_exclude]
+	# compile the regex pattern for faster searching
+	p = re.compile(f'({pattern})')  # wrap in parens to create regex group \1
 
 	matches = []
 	for card in cards:
@@ -36,7 +39,7 @@ def filter(cards,
 			continue
 		if create_date_max and card.create_date > create_date_max:
 			continue
-		if seen_date_min and card.seen_date < seen_date_max:
+		if seen_date_min and card.seen_date < seen_date_min:
 			continue
 		if seen_date_max and card.seen_date > seen_date_max:
 			continue
@@ -62,20 +65,22 @@ def filter(cards,
 			continue
 		if deleted_only and not card.deletedQ:
 			continue
-		if not_deleted_only and card.deletedQ:
+		if (not show_deleted and not deleted_only) and card.deletedQ:
+			continue
+		# pattern matchings
+		if pattern and not p.search(str(card)):
 			continue
 
 		matches.append(card)
 
-	return matches
-
-def query(cards, pattern, fancy=False):
-	# This lets us search our collection for a regular expression
-	# (Which would be better than anki!)
-
-	p = re.compile(f'({pattern})')  # wrap in parens to create regex group \1
-	matches = [c for c in cards if p.search(str(c))]
-	if fancy:
+	# post-processing
+	if invert:
+		matches = [c for c in cards if c not in matches]
+		# try using sets if things get slow
+	# sort by newest
+	matches.sort(key=lambda card: card.seen_date, reverse=True)
+	# color matching text in red
+	if pattern and not no_fancy:
 		for c in matches:
 			c.str = p.sub(f'{ansi["red"]}{ansi["bold"]}\\1' +
 				      f'{ansi["reset_color"]}{ansi["bold_off"]}',str(c))
