@@ -1,6 +1,9 @@
 from vinca.lib.ansi import ansi
 import shutil
 
+COLUMNS, LINES = shutil.get_terminal_size()
+TAB_WIDTH = 8
+
 # A Context Manager for the terminal's alternate screen
 class AlternateScreen:
 
@@ -14,12 +17,3 @@ class AlternateScreen:
 	def __exit__(self, *exception_args):
 		print(ansi['restore_screen'],end='')
 		print(ansi['show_cursor'] + ansi['restore_cursor'],end='')
-
-	@property
-	def lines(self):
-		return shutil.get_terminal_size().lines
-
-	@property
-	def columns(self):
-		return shutil.get_terminal_size().columns
-	
