@@ -11,11 +11,13 @@ DAY = datetime.timedelta(days=1)
 # type checking
 def deck_type(arg):
 	if arg.isdigit(): arg = int(arg)
-	assert arg in deckdict.keys(), 'Bad deck. Use [d] to list decks'
+	assert arg in deckdict.keys(), f'Bad deck {arg}. \
+		Use [d] to list decks'
 	return deckdict[arg]
 def card_type(arg):
 	assert arg.isdigit()
-	assert int(arg) in collection.id_list, 'Bad id. Use [q] to search for a card.'
+	assert int(arg) in collection.id_list, f'Bad id {arg}. \
+		Use [q] or [f] to search for a card.'
 	return classes.Card(arg)
 def deck_or_card(arg):
 	if arg.isdigit(): arg = int(arg)
@@ -39,8 +41,8 @@ def date_type(arg):
 	except:
 		raise argparse.ArgumentTypeError(f'''\n\n
 			Invalid Date: {arg}. Valid dates are:
-			1) -8		(relative to today)
-			2) 2021-06-03	(absolute)''')
+			1) -7		(one week ago)
+			2) 2021-06-03	(June 3rd)''')
 
 # argument parsing
 parser = argparse.ArgumentParser()
@@ -75,69 +77,42 @@ image_cloze_parser.add_argument('image_path',type=Path)
 image_cloze_parser.add_argument('decks',type=deck_type,nargs='*')
 image_cloze_parser.set_defaults(func = 'image_cloze')
 
+# QUERY
+query_parent = argparse.ArgumentParser('query_parent',add_help=False)
+query_parent.add_argument('pattern',nargs='?',default='')
+# optional args of browser.query function
+query_parent.add_argument('-v','--invert',action='store_true')
+query_parent.add_argument('--decks',type=deck_type,nargs='+', default=[])
+query_parent.add_argument('--cards',type=card_type,nargs='+', default=[])
+query_parent.add_argument('--tags_include',nargs='+', metavar='TAGS')
+query_parent.add_argument('--tags_exclude',nargs='+', metavar='TAGS')
+query_parent.add_argument('--create_date_min',type=date_type, metavar='DATE')
+query_parent.add_argument('--create_date_max',type=date_type, metavar='DATE')
+query_parent.add_argument('--seen_date_min',type=date_type, metavar='DATE')
+query_parent.add_argument('--seen_date_max',type=date_type, metavar='DATE')
+query_parent.add_argument('--due_date_min',type=date_type, metavar='DATE')
+query_parent.add_argument('--due_date_max',type=date_type, metavar='DATE')
+query_parent.add_argument('--due_only',action='store_true')
+query_parent.add_argument('--not_due_only',action='store_true')
+query_parent.add_argument('--editor', type=str)
+query_parent.add_argument('--reviewer', type=str)
+query_parent.add_argument('--scheduler', type=str)
+query_parent.add_argument('--deleted_only',action='store_true')
+query_parent.add_argument('--show_deleted',action='store_true')
+query_parent.add_argument('--new_only',action='store_true')
+query_parent.add_argument('--not_new_only',action='store_true')
+query_parent.add_argument('--no_fancy',action='store_true')
+query_parent.set_defaults(func = 'query')
+
 query_parser = subparsers.add_parser('query',aliases=['q'],
-	help='search collection for regexp')
-query_parser.add_argument('pattern',nargs='?',default='')
-query_parser.add_argument('-i', '--id_only',action='store_true',
-	help='only output the id of the match')
-query_parser.set_defaults(func = 'query')
-
-visual_query_parser = subparsers.add_parser('visual_query',aliases=['vq'],
-	help='search for regexp and perform command on the selected card')
-visual_query_parser.add_argument('pattern',nargs='?',default='')
-visual_query_parser.set_defaults(func = 'query', mode='visual')
-
-filter_parser = subparsers.add_parser('filter',aliases=['f'],
-	help='filter the collection')
-filter_parser.add_argument('-i','--id_only',action='store_true',
+	parents=[query_parent],
+	help='search collection for regexp and filter it')
+query_parser.add_argument('-i','--id_only',action='store_true',
 	help='only output the id of the match (facilitates piping)')
-# parameters which correspond to those of the browser.filter function
-filter_parser.add_argument('--decks',type=deck_type,nargs='+', default=[])
-filter_parser.add_argument('--cards',type=card_type,nargs='+', default=[])
-filter_parser.add_argument('--tags_include',nargs='+', metavar='TAGS')
-filter_parser.add_argument('--tags_exclude',nargs='+', metavar='TAGS')
-filter_parser.add_argument('--create_date_min',type=date_type, metavar='DATE')
-filter_parser.add_argument('--create_date_max',type=date_type, metavar='DATE')
-filter_parser.add_argument('--seen_date_min',type=date_type, metavar='DATE')
-filter_parser.add_argument('--seen_date_max',type=date_type, metavar='DATE')
-filter_parser.add_argument('--due_date_min',type=date_type, metavar='DATE')
-filter_parser.add_argument('--due_date_max',type=date_type, metavar='DATE')
-filter_parser.add_argument('--due_only',action='store_true')
-filter_parser.add_argument('--not_due_only',action='store_true')
-filter_parser.add_argument('--editor', type=str)
-filter_parser.add_argument('--reviewer', type=str)
-filter_parser.add_argument('--scheduler', type=str)
-filter_parser.add_argument('--deleted_only',action='store_true')
-filter_parser.add_argument('--not_deleted_only',action='store_true')
-filter_parser.add_argument('--new_only',action='store_true')
-filter_parser.add_argument('--not_new_only',action='store_true')
-filter_parser.set_defaults(func = 'filter')
-
-
-visual_filter_parser = subparsers.add_parser('visual_filter',aliases=['vf'],
-	help='filter the collection and select a card')
-# parameters which correspond to those of the browser.filter function
-visual_filter_parser.add_argument('--decks',type=deck_type,nargs='+',default=[])
-visual_filter_parser.add_argument('--cards',type=card_type,nargs='+',default=[])
-visual_filter_parser.add_argument('--tags_include',nargs='+', metavar='TAGS')
-visual_filter_parser.add_argument('--tags_exclude',nargs='+', metavar='TAGS')
-visual_filter_parser.add_argument('--create_date_min',type=date_type, metavar='DATE')
-visual_filter_parser.add_argument('--create_date_max',type=date_type, metavar='DATE')
-visual_filter_parser.add_argument('--seen_date_min',type=date_type, metavar='DATE')
-visual_filter_parser.add_argument('--seen_date_max',type=date_type, metavar='DATE')
-visual_filter_parser.add_argument('--due_date_min',type=date_type, metavar='DATE')
-visual_filter_parser.add_argument('--due_date_max',type=date_type, metavar='DATE')
-visual_filter_parser.add_argument('--due_only',action='store_true')
-visual_filter_parser.add_argument('--not_due_only',action='store_true')
-visual_filter_parser.add_argument('--editor', type=str)
-visual_filter_parser.add_argument('--reviewer', type=str)
-visual_filter_parser.add_argument('--scheduler', type=str)
-visual_filter_parser.add_argument('--deleted_only',action='store_true')
-visual_filter_parser.add_argument('--not_deleted_only',action='store_true')
-visual_filter_parser.add_argument('--new_only',action='store_true')
-visual_filter_parser.add_argument('--not_new_only',action='store_true')
-visual_filter_parser.set_defaults(func = 'filter', mode='visual')
-
+visual_query_parser = subparsers.add_parser('visual_query',aliases=['vq'],
+	parents=[query_parent],
+	help='search for regexp, filter it, and perform command on the selected card')
+visual_query_parser.set_defaults(mode='visual')
 
 # commands which take a deck or several cards as an argument 
 study_parser = subparsers.add_parser('study',aliases=['s'],
@@ -147,6 +122,13 @@ study_parser.add_argument('--date', type=int,
 	help='study as if today was [date]')
 study_parser.set_defaults(func = 'study')
 
+preview_parser = subparsers.add_parser('preview',aliases=['p'],
+	help='preview the collection or selected deck')
+preview_parser.add_argument('decks_or_cards', type=deck_or_card, nargs='*')
+preview_parser.add_argument('--date', type=int,
+	help='preview as if today was [date]')
+preview_parser.set_defaults(func = 'preview')
+
 statistics_parser = subparsers.add_parser('statistics',aliases=['S'],
 	help='statistics about the selected deck or card')
 statistics_parser.add_argument('decks_or_cards', type=deck_or_card, nargs='*')
@@ -163,19 +145,21 @@ delete_parser.add_argument('decks_or_cards',type=deck_or_card, nargs='*')
 delete_parser.set_defaults(func = 'delete')
 
 # commands which take no arguments
+# DECKS
 list_decks_parser = subparsers.add_parser('list_decks',aliases=['d'],
 	help='list decks')
 list_decks_parser.set_defaults(func = 'list_decks')
-
 visual_decks_parser = subparsers.add_parser('visual_decks',aliases=['vd'],
 	help='select a deck and perform a command on it')
 visual_decks_parser.set_defaults(func = 'list_decks', mode='visual')
 
-purge_parser = subparsers.add_parser('purge',aliases=['p'],
+# PURGE
+purge_parser = subparsers.add_parser('purge',
 	help='permanently delete all cards scheduled for deletion')
 purge_parser.set_defaults(func = 'purge')
 
 # commands which take a path as an argument (import / backup)
+# IMPORT EXPORT
 backup_parser = subparsers.add_parser('backup',aliases=['b','export'],
 	help='backup all cards')
 backup_parser.add_argument('backup_dest',type=Path)
@@ -188,3 +172,6 @@ import_parser.add_argument('import_path',type=Path)
 import_parser.add_argument('-o','--overwrite',action='store_true',
 	help='overwrite the existing collection')
 import_parser.set_defaults(func = 'import_collection')
+
+def get_parser():
+	return parser
